==> SQLMatches-0.3.1.tar.gz: SQLMatches-0.3.1/SQLMatches/routes/api/profile.py <==
# -*- coding: utf-8 -*-

"""
GNU General Public License v3.0 (GPL v3)
Copyright (c) 2020-2021 WardPearce
Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""


from starlette.endpoints import HTTPEndpoint
from starlette.authentication import requires
from starlette.requests import Request

from ...responses import response

from ...caches import CommunityCache


class ProfileAPI(HTTPEndpoint):
    @requires("community")
    async def get(self, request: Request) -> response:
        """Gets profile of community player.

        Parameters
        ----------
        request : Request
        parameters : dict

        Returns
        -------
        response
        """

        cache = CommunityCache(
            request.state.community.community_name
        ).profile(request.path_params["steam_id"])

        cache_get = await cache.get()
        if cache_get:
            return response(cache_get)

        data = (await request.state.community.profile(
            request.path_params["steam_id"]
        )).api_schema

        await cache.set(data, ttl=30)

        return response(data)

==> SQLMatches-0.3.3.tar.gz: SQLMatches-0.3.3/SQLMatches/routes/api/profile.py <==
# -*- coding: utf-8 -*-

"""
GNU General Public License v3.0 (GPL v3)
Copyright (c) 2020-2021 WardPearce
Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""


from starlette.endpoints import HTTPEndpoint
from starlette.authentication import requires
from starlette.requests import Request
from starlette.responses import (
    PlainTextResponse,
    Response
)

from ...responses import response
from ...resources import Sessions

from ...caches import CommunityCache


class SteamProfileCors(HTTPEndpoint):
    async def get(self, request: Request) -> PlainTextResponse:
        async with Sessions.aiohttp.get(
            "https://steamcommunity.com/profiles/{}?xml=1".format(
                request.path_params["steam_id"])) as resp:

            if resp.status == 200:
                return PlainTextResponse(await resp.text())
            else:
                return Response(status_code=500)


class ProfileAPI(HTTPEndpoint):
    @requires("community")
    async def get(self, request: Request) -> response:
        """Gets profile of community player.

        Parameters
        ----------
        request : Request
        parameters : dict

        Returns
        -------
        response
        """

        cache = CommunityCache(
            request.state.community.community_name
        ).profile(request.path_params["steam_id"])

        cache_get = await cache.get()
        if cache_get:
            return response(cache_get)

        data = (await request.state.community.profile(
            request.path_params["steam_id"]
        )).api_schema

        await cache.set(data, ttl=30)

        return response(data)
